#include <fstream>
#include <string>
#include <vector>

//Start Function prototypes for functions used before being defined
int readVec(char *fToGo,vector<double> *vec);

//Start Function definitions
void myDummyFit(int eValI){

  //Create some dummy data to put into a file
  double fitValue = 100000.0*eValI/1000;
  double fitErr   = 1000.01*eValI/1000;
 
  //Write values to file
  ofstream myfile;
  char  fString[120];
  sprintf(fString,"./dat/Fit_%d.dat",eValI);
  myfile.open (fString);               //Open the file
  myfile<<setprecision(16)<<fitValue;  //Write fitValue on first line
  endl(myfile);                        //End the first line
  myfile<<setprecision(16)<<fitErr;    //Write fitErr on the second line
  endl(myfile);                        //End the second line
  myfile.close();                      //Close the file
  return;
}

void myDummyNormYield(void){
  gROOT->Reset();
  gROOT->SetStyle("Plain");
  gStyle->SetOptStat(0);
  
  char  fString[120];
  vector<double> yieldVec;

  TH1D * myNormedYield = new TH1D("myYield","",5,8.0,9.0);
  TH1D * myYieldMeVBinned = new TH1D("myYieldMeVBinned","",5,8000,9000);  

  //Get the original normalization histogram
  TFile *hFileNorm = new TFile("./norm/normAll.root");
  TH1F *hNormOriginal; hFileNorm->GetObject("tagged_flux",hNormOriginal);
  hNormOriginal->SetName("hNormOriginal");

  //GET THE YIELDS

  int nBins = myNormedYield->GetNbinsX();//Find how many bins are in myNormedYield

  for (int iBin=1; iBin<=nBins; iBin++) {//Loop over all bins

    //Get normalization value and error from histogram
    int eValI = (int) myYieldMeVBinned->GetBinCenter(iBin);//In MeV
    double eValGeV = eValI/1000.0;//In GeV
    int normBin = hNormOriginal->FindBin(eValGeV);
    double normVal = hNormOriginal->GetBinContent(normBin);
    double normErr = hNormOriginal->GetBinError(normBin);
    //cout<<"normVal = "<<normVal<<endl;

    //Get yield value and error from files
    sprintf(fString,"./dat/Fit_%d.dat",eValI);//Create the file string
    yieldVec.clear();//Clear the vector each time before filling
                     //with new values
    readVec(fString,&yieldVec);//Put the file contents into the vector
    double yVal = yieldVec[0];
    double yErr = yieldVec[1];

    //Create the normalized yield and error
    double normYieldVal = yVal/normVal;
    double normYieldErr = 
      normYieldVal*sqrt(pow(yErr/yVal,2) + pow(normErr/normVal,2));
    
    //Place yeild and errors into histogram
    myNormedYield->SetBinContent(iBin,normYieldVal);
    myNormedYield->SetBinError(iBin,normYieldErr);
  }

  myNormedYield->Draw();

  return;
}

int readVec(char *fToGo,vector<double> *vec)
{
  string line;
  stringstream os(line);
  string temp;
  ifstream myfile (fToGo);
  if (myfile.is_open())
    {
      int j = 0;
      while ( myfile.good() )
        {
          int i = 0;
          getline(myfile,line);
          stringstream os(line);
          while (os >> temp) {
            vec->push_back(atof(temp.c_str()));
            i++;
          }
          j++;
        }
      myfile.close();
    }
  else cout << "Unable to open file";
  return 0;
}
